import { Adapter, ILoggingInterface, LoggingTypes } from "./types.js";
export interface ILoggingOptions {
    /**
     * Name will be prefixed on Console output and added to logfiles, if not specified here
     */
    name: string;
    /**
     * Prints output to console
     */
    console: boolean;
    /**
     * Enables printing of calling file
     */
    resolve_filename: boolean;
}
export interface INativeFunctions {
    startTimer(): any;
    endTimer(start: any): number;
}
export declare const DefaultNativeFunctions: INativeFunctions;
declare const InitialisedAdapters: unique symbol;
export declare abstract class LoggingInterface implements ILoggingInterface {
    #private;
    get names(): string[];
    protected abstract message(type: LoggingTypes, names: string[], message: any[], caller?: {
        file: string;
        line: number;
        column?: number;
    }): void;
    constructor(names: string[]);
    debug(...message: any[]): void;
    log(...message: any[]): void;
    warning(...message: any[]): void;
    warn(...message: any[]): void;
    error(error: Error | string, ...message: any[]): void;
    time(id?: string): {
        id: string;
        end: () => number;
    };
    timeEnd(id: string): number;
    abstract getChild(name: string): ILoggingInterface;
}
export declare class LoggingBase extends LoggingInterface {
    #private;
    private static [InitialisedAdapters];
    static nativeFunctions: INativeFunctions;
    static DecoupledLogging: any;
    set logLevel(level: LoggingTypes);
    get logLevel(): LoggingTypes;
    constructor(options?: Partial<ILoggingOptions>);
    addAdapter(adapter: Adapter): Promise<void>;
    getChild(name: string): ILoggingInterface;
    protected message(type: LoggingTypes, names: string[], message: any[], caller?: {
        file: string;
        line: number;
        column?: number;
    }): void;
    close(): Promise<void>;
}
export declare function removeColors(text: string): string;
export {};
