export declare enum LoggingTypes {
    Debug = 0,
    Log = 1,
    Warn = 2,
    Error = 3
}
export declare const TerminalFormats: {
    Reset: string;
    Bold: string;
    Underscore: string;
    Blink: string;
    Reverse: string;
    Hidden: string;
    FgBlack: string;
    FgRed: string;
    FgGreen: string;
    FgYellow: string;
    FgBlue: string;
    FgMagenta: string;
    FgCyan: string;
    FgWhite: string;
    BgBlack: string;
    BgRed: string;
    BgGreen: string;
    BgYellow: string;
    BgBlue: string;
    BgMagenta: string;
    BgCyan: string;
    BgWhite: string;
};
export declare enum IColors {
    NONE = 0,
    RED = 1,
    GREEN = 2,
    YELLOW = 3,
    BLUE = 4,
    MAGENTA = 5,
    CYAN = 6,
    WHITE = 7
}
export interface IFormatted<T = any> {
    color?: IColors;
    bgcolor?: IColors;
    bold?: boolean;
    italic?: boolean;
    blink?: boolean;
    underscore?: boolean;
    content: T;
}
export declare class Formatted<T = any> implements IFormatted<T> {
    static strip(formatted: IFormatted<string> | IFormatted<string>[]): string;
    constructor(content?: T, apply?: Formatted);
    color?: IColors;
    bgcolor?: IColors;
    bold?: boolean;
    italic?: boolean;
    blink?: boolean;
    underscore?: boolean;
    content: T;
    _color(c: IColors): this;
    _bgcolor(c: IColors): this;
    _bold(active?: boolean): this;
    _italic(active?: boolean): this;
    _blink(active?: boolean): this;
}
export declare const Format: {
    none: (content: any) => Formatted<any>;
    red: (content: any) => Formatted<any>;
    green: (content: any) => Formatted<any>;
    yellow: (content: any) => Formatted<any>;
    blue: (content: any) => Formatted<any>;
    magenta: (content: any) => Formatted<any>;
    cyan: (content: any) => Formatted<any>;
    white: (content: any) => Formatted<any>;
    bgnone: (content: any) => Formatted<any>;
    bgred: (content: any) => Formatted<any>;
    bggreen: (content: any) => Formatted<any>;
    bgyellow: (content: any) => Formatted<any>;
    bgblue: (content: any) => Formatted<any>;
    bgmagenta: (content: any) => Formatted<any>;
    bgcyan: (content: any) => Formatted<any>;
    bgwhite: (content: any) => Formatted<any>;
    bold: (content: any) => Formatted<any>;
    italic: (content: any) => Formatted<any>;
};
export interface FormatConfig {
    error: Formatted;
    warning: Formatted;
    log: Formatted;
    debug: Formatted;
    date: Formatted;
    file: Formatted;
    names: Formatted;
    names_delimiter: Formatted;
}
export declare class DefaultFormatConfig implements FormatConfig {
    error: Formatted<any>;
    warning: Formatted<any>;
    log: Formatted<any>;
    debug: Formatted<any>;
    date: Formatted<any>;
    file: Formatted<any>;
    names: Formatted<any>;
    names_delimiter: Formatted<string>;
}
export interface Message {
    type: LoggingTypes;
    names?: string[];
    text: IFormatted<string>[];
    date: Date;
    file: string;
}
export interface Adapter {
    readonly level: LoggingTypes;
    /**
     * This function initialises the Adapter. It might be called multiple times, when added to multiple instances
     * @param observable An observable to subscribe to messages
     */
    init(): void | Promise<void>;
    flush(sync: true): void;
    flush(sync: false): void | Promise<void>;
    setLevel(level: LoggingTypes): void;
    onMessage(message: Message): void;
    /**
     * When a close function is available, it will be called when no logging instance references it anymore.
     *
     * WARNING: The adapter might be reinitialised, when it is added to a new Logging instance
     */
    close?(): void;
}
export interface ILoggingTimer {
    end: () => number;
}
export interface ILoggingInterface {
    debug(...message: any[]): void;
    log(...message: any[]): void;
    warn(...message: any[]): void;
    error(...message: any[]): void;
    time(name?: string): ILoggingTimer;
    timeEnd(id: string): number;
    getChild(name: string): ILoggingInterface;
}
