export var LoggingTypes;
(function (LoggingTypes) {
    LoggingTypes[LoggingTypes["Debug"] = 0] = "Debug";
    LoggingTypes[LoggingTypes["Log"] = 1] = "Log";
    LoggingTypes[LoggingTypes["Warn"] = 2] = "Warn";
    LoggingTypes[LoggingTypes["Error"] = 3] = "Error";
})(LoggingTypes || (LoggingTypes = {}));
export const TerminalFormats = {
    Reset: "\x1b[0m",
    Bold: "\x1b[1m",
    Underscore: "\x1b[4m",
    Blink: "\x1b[5m",
    Reverse: "\x1b[7m",
    Hidden: "\x1b[8m",
    FgBlack: "\x1b[30m",
    FgRed: "\x1b[31m",
    FgGreen: "\x1b[32m",
    FgYellow: "\x1b[33m",
    FgBlue: "\x1b[34m",
    FgMagenta: "\x1b[35m",
    FgCyan: "\x1b[36m",
    FgWhite: "\x1b[37m",
    BgBlack: "\x1b[40m",
    BgRed: "\x1b[41m",
    BgGreen: "\x1b[42m",
    BgYellow: "\x1b[43m",
    BgBlue: "\x1b[44m",
    BgMagenta: "\x1b[45m",
    BgCyan: "\x1b[46m",
    BgWhite: "\x1b[47m",
};
export var IColors;
(function (IColors) {
    IColors[IColors["NONE"] = 0] = "NONE";
    IColors[IColors["RED"] = 1] = "RED";
    IColors[IColors["GREEN"] = 2] = "GREEN";
    IColors[IColors["YELLOW"] = 3] = "YELLOW";
    IColors[IColors["BLUE"] = 4] = "BLUE";
    IColors[IColors["MAGENTA"] = 5] = "MAGENTA";
    IColors[IColors["CYAN"] = 6] = "CYAN";
    IColors[IColors["WHITE"] = 7] = "WHITE";
})(IColors || (IColors = {}));
export class Formatted {
    static strip(formatted) {
        if (Array.isArray(formatted)) {
            return formatted.reduce((p, c) => p + c.content, "");
        }
        else {
            return formatted.content;
        }
    }
    constructor(content, apply) {
        if (content instanceof Formatted) {
            this.color = content.color;
            this.bgcolor = content.bgcolor;
            this.bold = content.bold;
            this.italic = content.italic;
            this.blink = content.blink;
            this.underscore = content.underscore;
            this.content = content.content;
        }
        else {
            this.content = content;
        }
        if (apply) {
            this.color = apply.color;
            this.bgcolor = apply.bgcolor;
            this.bold = apply.bold;
            this.italic = apply.italic;
            this.blink = apply.blink;
            this.underscore = apply.underscore;
        }
    }
    color;
    bgcolor;
    bold;
    italic;
    blink;
    underscore;
    content;
    _color(c) {
        this.color = c;
        return this;
    }
    _bgcolor(c) {
        this.bgcolor = c;
        return this;
    }
    _bold(active = true) {
        this.bold = active;
        return this;
    }
    _italic(active = true) {
        this.italic = active;
        return this;
    }
    _blink(active = true) {
        this.blink = active;
        return this;
    }
}
const AddColorFormat = (color) => (content) => {
    if (content instanceof Formatted) {
        content.color = color;
        return content;
    }
    else {
        const d = new Formatted(content);
        d.color = color;
        return d;
    }
};
const AddBGColorFormat = (color) => (content) => {
    if (content instanceof Formatted) {
        content.bgcolor = color;
        return content;
    }
    else {
        const d = new Formatted(content);
        d.bgcolor = color;
        return d;
    }
};
export const Format = {
    none: AddColorFormat(IColors.NONE),
    red: AddColorFormat(IColors.RED),
    green: AddColorFormat(IColors.GREEN),
    yellow: AddColorFormat(IColors.YELLOW),
    blue: AddColorFormat(IColors.BLUE),
    magenta: AddColorFormat(IColors.MAGENTA),
    cyan: AddColorFormat(IColors.CYAN),
    white: AddColorFormat(IColors.WHITE),
    bgnone: AddBGColorFormat(IColors.NONE),
    bgred: AddBGColorFormat(IColors.RED),
    bggreen: AddBGColorFormat(IColors.GREEN),
    bgyellow: AddBGColorFormat(IColors.YELLOW),
    bgblue: AddBGColorFormat(IColors.BLUE),
    bgmagenta: AddBGColorFormat(IColors.MAGENTA),
    bgcyan: AddBGColorFormat(IColors.CYAN),
    bgwhite: AddBGColorFormat(IColors.WHITE),
    bold: (content) => {
        if (content instanceof Formatted) {
            content.bold = true;
            return content;
        }
        else {
            const d = new Formatted(content);
            d.bold = true;
            return d;
        }
    },
    italic: (content) => {
        if (content instanceof Formatted) {
            content.italic = true;
            return content;
        }
        else {
            const d = new Formatted(content);
            d.italic = true;
            return d;
        }
    },
};
export class DefaultFormatConfig {
    error = new Formatted()._color(IColors.RED)._bold();
    warning = new Formatted()._color(IColors.YELLOW)._bold();
    log = new Formatted()._color(IColors.NONE)._bold();
    debug = new Formatted()._color(IColors.CYAN)._bold();
    date = new Formatted()._color(IColors.NONE);
    file = new Formatted()._color(IColors.NONE);
    names = new Formatted()._bold()._color(IColors.CYAN);
    names_delimiter = new Formatted(" -> ")._bold();
}
//# sourceMappingURL=types.js.map